@@ -539,4 +539,59 @@ BOOST_AUTO_TEST_CASE( add_const_part )
 	free(data);
 }
 
+BOOST_AUTO_TEST_CASE( add_nocopy )
+{
+    zmqpp::message msg;
+    const char *const_data = "hello";
+    void* data = malloc(15);
+    memcpy(data, "a_longer_hello", 14);
+
+    //msg.add_nocopy(const_data, 5); should trigger static assert.
+
+    msg.add_nocopy_const(const_data, 5);
+    msg.add_nocopy(data, 14);
+
+    // This is what you MUST NOT do, even though it compiles fine.
+    //char *raw = static_cast<char *>(zmq_msg_data(&msg.raw_msg(0)));
+    //raw[0] = 'c'; // crash
+
+    // However you can do that on non-const data.
+    char *raw = static_cast<char *>(zmq_msg_data(&msg.raw_msg(1)));
+    raw[0] = '_';
+
+    BOOST_REQUIRE_EQUAL(2, msg.parts());
+    BOOST_CHECK_EQUAL(5, msg.size(0));
+    BOOST_CHECK_EQUAL(14, msg.size(1));
+    BOOST_CHECK_EQUAL("hello", msg.get(0));
+    BOOST_CHECK_EQUAL("__longer_hello", msg.get(1)); // we changed 1 byte
+
+    free(data);
+}
+
+BOOST_AUTO_TEST_CASE( remove )
+{
+    size_t partRemoved = 1;
+    std::array<std::string, 3> parts = {{
+        "a long test frame 1 to go over the small message size limitation",
+        "another frame 2",
+        "some final frame 3"
+    }};
+
+    zmqpp::message message;
+    message << parts[0] << parts[1] << parts[2];
+
+    BOOST_REQUIRE_EQUAL( parts.size(), message.parts() );
+
+    message.remove(partRemoved);
+    BOOST_REQUIRE_EQUAL( parts.size() - 1, message.parts() );
+    for( size_t i = 0; i < parts.size() - 1; ++i )
+    {
+        if (i == partRemoved)
+            continue;
+
+        BOOST_CHECK_EQUAL( parts[i].size(), message.size(i) );
+        BOOST_CHECK_EQUAL( parts[i], message.get(i) );
+    }
+}
+
 BOOST_AUTO_TEST_SUITE_END()
