@@ -55,7 +55,7 @@ BOOST_AUTO_TEST_CASE( socket_creation )
 BOOST_AUTO_TEST_CASE( socket_creation_bad_type )
 {
 	zmqpp::context context;
-	BOOST_CHECK_THROW(zmqpp::socket socket(context, static_cast<zmqpp::socket_type>(-1)), zmqpp::zmq_internal_exception)
+	BOOST_CHECK_THROW(zmqpp::socket socket(context, static_cast<zmqpp::socket_type>(-1)), zmqpp::zmq_internal_exception);
 }
 
 BOOST_AUTO_TEST_CASE( valid_socket )
@@ -102,6 +102,58 @@ BOOST_AUTO_TEST_CASE( simple_pull_push )
 	BOOST_CHECK(!puller.has_more_parts());
 }
 
+BOOST_AUTO_TEST_CASE( simple_receive_raw )
+{
+	zmqpp::context context;
+	char buf[64];
+	size_t len;
+
+	zmqpp::socket puller(context, zmqpp::socket_type::pull);
+	puller.bind("inproc://test");
+
+	zmqpp::socket pusher(context, zmqpp::socket_type::push);
+	pusher.connect("inproc://test");
+
+	BOOST_CHECK(pusher.send("hello world!"));
+
+	wait_for_socket(puller);
+
+	len = sizeof(buf);
+	BOOST_CHECK(puller.receive_raw(buf, len));
+
+	std::string message(buf, len);
+	BOOST_CHECK_EQUAL("hello world!", message);
+	BOOST_CHECK(!puller.has_more_parts());
+}
+
+BOOST_AUTO_TEST_CASE( simple_receive_raw_short_buf )
+{
+	zmqpp::context context;
+	char buf[64];
+	size_t len;
+
+	zmqpp::socket puller(context, zmqpp::socket_type::pull);
+	puller.bind("inproc://test");
+
+	zmqpp::socket pusher(context, zmqpp::socket_type::push);
+	pusher.connect("inproc://test");
+
+	BOOST_CHECK(pusher.send("hello world!"));
+
+	wait_for_socket(puller);
+
+	memset(buf, 0xee, sizeof(buf));
+	len = 5;
+	BOOST_CHECK(puller.receive_raw(buf, len));
+
+	BOOST_CHECK_EQUAL(5, len);
+	BOOST_CHECK_EQUAL(0xee, buf[5] & 0xff);
+	BOOST_CHECK_EQUAL(0xee, buf[6] & 0xff);
+	std::string message(buf, len);
+	BOOST_CHECK_EQUAL("hello", message);
+	BOOST_CHECK(!puller.has_more_parts());
+}
+
 BOOST_AUTO_TEST_CASE( multipart_pair )
 {
 	zmqpp::context context;
@@ -508,23 +560,55 @@ BOOST_AUTO_TEST_CASE( test_simple_monitor )
     zmqpp::socket client(ctx, zmqpp::socket_type::pull);
     client.connect("tcp://localhost:55443");
 
-    zmqpp::message_t message;
-    BOOST_CHECK( monitor.receive( message ) );
-    BOOST_REQUIRE_EQUAL(2, message.parts());
+    // Receive event accepted
+    {
+        zmqpp::message_t message;
+        BOOST_CHECK( monitor.receive( message ) );
+        BOOST_REQUIRE_EQUAL(2, message.parts());
 
 #if (ZMQ_VERSION_MINOR >= 1)
-    const uint8_t *ptr = reinterpret_cast<const uint8_t *>(message.raw_data(0));
-    uint16_t ev = *(reinterpret_cast<const uint16_t *>(ptr));
-    // uint32_t value = *(reinterpret_cast<const uint32_t *>(ptr + 2));
-    BOOST_CHECK_EQUAL( zmqpp::event::accepted, ev );
-    BOOST_CHECK_EQUAL("tcp://0.0.0.0:55443", message.get(1));
-    // value is the underlying file descriptor. we cannot check its value against anything meaningful
+        const uint8_t *ptr = reinterpret_cast<const uint8_t *>(message.raw_data(0));
+        uint16_t ev = *(reinterpret_cast<const uint16_t *>(ptr));
+        // uint32_t value = *(reinterpret_cast<const uint32_t *>(ptr + 2));
+        BOOST_CHECK_EQUAL( zmqpp::event::accepted, ev );
+        BOOST_CHECK_EQUAL("tcp://0.0.0.0:55443", message.get(1));
+        // value is the underlying file descriptor. we cannot check its value against anything meaningful
 #else
-    zmq_event_t const* event = static_cast<zmq_event_t const*>( message.raw_data(0) );
-    BOOST_CHECK_EQUAL( zmqpp::event::accepted, event->event );
-    BOOST_CHECK_EQUAL( 0, event->value );
-    BOOST_CHECK_EQUAL("tcp://0.0.0.0:55443", message.get(1));
+        zmq_event_t const* event = static_cast<zmq_event_t const*>( message.raw_data(0) );
+        BOOST_CHECK_EQUAL( zmqpp::event::accepted, event->event );
+        BOOST_CHECK_EQUAL( 0, event->value );
+        BOOST_CHECK_EQUAL("tcp://0.0.0.0:55443", message.get(1));
 #endif
+    }
+
+    server.unmonitor();
+
+    zmqpp::socket client2(ctx, zmqpp::socket_type::pull);
+    client2.connect("tcp://localhost:55443");
+
+    // Receive event monitor_stopped
+    {
+        zmqpp::message_t message;
+        BOOST_CHECK( monitor.receive( message ) );
+        BOOST_REQUIRE_EQUAL(2, message.parts());
+
+#if (ZMQ_VERSION_MINOR >= 1)
+        const uint8_t *ptr = reinterpret_cast<const uint8_t *>(message.raw_data(0));
+        uint16_t ev = *(reinterpret_cast<const uint16_t *>(ptr));
+        // uint32_t value = *(reinterpret_cast<const uint32_t *>(ptr + 2));
+        BOOST_CHECK_EQUAL( zmqpp::event::monitor_stopped, ev );
+#else
+        zmq_event_t const* event = static_cast<zmq_event_t const*>( message.raw_data(0) );
+        BOOST_CHECK_EQUAL( zmqpp::event::monitor_stopped, event->event );
+#endif
+    }
+
+    // Receive nothing else
+    {
+        zmqpp::message_t message;
+        BOOST_CHECK( !monitor.receive( message, true ) );
+    }
+
 }
 #endif
 
