@@ -32,7 +32,7 @@ BOOST_AUTO_TEST_SUITE( socket_options )
 template<typename CheckType, typename WantedType>
 void try_set(zmqpp::socket& socket, zmqpp::socket_option const& option, CheckType const& value, std::string const& option_name, std::string const& value_type)
 {
-	BOOST_CHECKPOINT("setting option " << option_name << " against set type '" << value_type << "'");
+	BOOST_TEST_CHECKPOINT("setting option " << option_name << " against set type '" << value_type << "'");
 	try
 	{
 		socket.set(option, value);
@@ -51,7 +51,7 @@ void try_set(zmqpp::socket& socket, zmqpp::socket_option const& option, CheckTyp
 template<typename CheckType, typename WantedType>
 void try_get(zmqpp::socket const& socket, zmqpp::socket_option const& option, std::string const& option_name, std::string const& value_type)
 {
-	BOOST_CHECKPOINT("getting option " << option_name << " against set type '" << value_type << "'");
+	BOOST_TEST_CHECKPOINT("getting option " << option_name << " against set type '" << value_type << "'");
 	try
 	{
 		CheckType value;
@@ -358,7 +358,7 @@ BOOST_AUTO_TEST_CASE( get_socket_options_tcp_only )
 {
 	zmqpp::context context;
 	zmqpp::socket socket(context, zmqpp::socket_type::subscribe);
-	socket.bind("tcp://*:54321");
+	socket.bind("tcp://*:54322");
 
 // TODO: reenable once I have curve key generation working to test against
 //	CHECK_GET(socket, std::string, curve_public_key);
@@ -367,4 +367,15 @@ BOOST_AUTO_TEST_CASE( get_socket_options_tcp_only )
 //  CHECK_NOGET(socket, curve_server);
 }
 #endif
+#if (ZMQ_VERSION_MAJOR > 4) || ((ZMQ_VERSION_MAJOR == 4) && (ZMQ_VERSION_MINOR >= 2))
+BOOST_AUTO_TEST_CASE( use_fd_socket_option )
+{
+	zmqpp::context context;
+	zmqpp::socket socket(context, zmqpp::socket_type::push);
+	CHECK_GET(socket, int, use_fd);
+	CHECK_SET(socket, int, use_fd);
+	CHECK_GET(socket, int, use_fd);
+}
+#endif
+
 BOOST_AUTO_TEST_SUITE_END()
