@@ -21,16 +21,6 @@
 namespace zmqpp
 {
 
-const long poller::wait_forever = -1;
-const short poller::poll_none   = 0;
-const short poller::poll_in     = ZMQ_POLLIN;
-const short poller::poll_out    = ZMQ_POLLOUT;
-const short poller::poll_error  = ZMQ_POLLERR;
-
-#if ((ZMQ_VERSION_MAJOR == 4 && ZMQ_VERSION_MINOR >= 2) || ZMQ_VERSION_MAJOR > 4)
-const short poller::poll_pri    = ZMQ_POLLPRI;
-#endif
-
 poller::poller()
 	: _items()
 	, _index()
